@@ -1,4 +1,4 @@
-# $Id: wcloud.py 1074 2014-10-21 15:14:45Z mwall $
+# $Id: wcloud.py 1080 2014-10-22 13:43:08Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -31,7 +31,7 @@ import weewx.units
 import weewx.wxformulas
 from weeutil.weeutil import to_bool
 
-VERSION = "0.4"
+VERSION = "0.5"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: WeatherCloud: %s' % msg)
@@ -243,11 +243,19 @@ class WeatherCloudThread(weewx.restx.RESTThread):
             if u is not None:
                 self.archive_units = u[0]
         rec = super(WeatherCloudThread, self).get_record(record, archive)
+
+        # put everything into units required by weathercloud
+        rec = weewx.units.to_METRICWX(rec)
+
+        # calculate additional quantities
         rec['windavg'] = _get_windavg(archive, record['dateTime'])
-        rec['windavg'] = _convert_windspeed(rec['windavg'], self.archive_units)
         rec['windhi'] = _get_windhi(archive, record['dateTime'])
-        rec['windhi'] = _convert_windspeed(rec['windhi'], self.archive_units)
         rec['winddiravg'] = _get_winddiravg(archive, record['dateTime'])
+
+        # these observations are non-standard, so do unit conversions directly
+        rec['windavg'] = _convert_windspeed(rec['windavg'], self.archive_units)
+        rec['windhi'] = _convert_windspeed(rec['windhi'], self.archive_units)
+
         if 'inTemp' in rec and 'inHumidity' in rec:
             rec['inheatindex'] = weewx.wxformulas.heatindexC(
                 rec['inTemp'], rec['inHumidity'])
@@ -267,10 +275,7 @@ class WeatherCloudThread(weewx.restx.RESTThread):
             rec['bat05'] = _invert(record['inTempBatteryStatus'])
         return rec
 
-    def get_url(self, in_record):
-        # put everything into the right units and scaling
-        record = weewx.units.to_METRICWX(in_record)
-
+    def get_url(self, record):
         # put data into expected structure and format
         values = {}
         values['ver'] = str(weewx.__version__)
